@@ -663,18 +663,18 @@ class cmd_link_tree(BzrToolsCommand):
         finally:
             target_tree.unlock()
 
-
+from heads import cmd_heads
 commands = [
             cmd_baz_import,
             cmd_baz_import_branch,
             cmd_branches,
-            cmd_trees,
             cmd_branch_history,
             cmd_cbranch,
             cmd_cdiff,
             cmd_clean_tree,
             cmd_fetch_ghosts,
             cmd_graph_ancestry,
+            cmd_heads,
             cmd_import,
             cmd_link_tree,
             cmd_multi_pull,
@@ -683,6 +683,7 @@ commands = [
             cmd_shelf,
             cmd_shell,
             cmd_shelve,
+            cmd_trees,
             cmd_unshelve,
             cmd_zap,
             ]
@@ -700,7 +701,9 @@ def test_suite():
     from unittest import TestSuite
     import bzrtools
     import tests.clean_tree
+    import tests.test_dotgraph
     import tests.is_clean
+    import tests.test_cbranch
     import tests.test_link_tree
     import tests.test_patch
     import tests.test_rspush
@@ -721,8 +724,10 @@ def test_suite():
     result.addTest(tests.blackbox.test_suite())
     result.addTest(tests.upstream_import.test_suite())
     result.addTest(zap.test_suite())
+    result.addTest(TestLoader().loadTestsFromModule(tests.test_dotgraph))
     result.addTest(TestLoader().loadTestsFromModule(tests.is_clean))
     result.addTest(TestLoader().loadTestsFromModule(tests.test_link_tree))
     result.addTest(TestLoader().loadTestsFromModule(tests.test_patch))
     result.addTest(TestLoader().loadTestsFromModule(tests.test_rspush))
+    result.addTest(TestLoader().loadTestsFromModule(tests.test_cbranch))
     return result
