@@ -30,7 +30,7 @@ from bzrlib.commit import Commit, NullCommitReporter
 from bzrlib.commands import Command
 from bzrlib.option import _global_option, Option
 from bzrlib.merge import merge_inner
-from bzrlib.revision import NULL_REVISION
+from bzrlib.revision import NULL_REVISION, is_null
 import bzrlib.ui
 import bzrlib.ui.text
 from bzrlib.workingtree import WorkingTree
@@ -42,7 +42,7 @@ try:
     from pybaz.backends.baz import null_cmd
 except ImportError:
     raise NoPyBaz
-from fai import iter_new_merges, direct_merges
+from baz_helper import iter_new_merges, direct_merges
 import tempfile
 import os
 import os.path
@@ -293,7 +293,7 @@ def get_remaining_revisions(output_dir, version, encoding,
         last_patch, last_encoding = get_last_revision(branch)
         assert encoding == last_encoding
         if last_patch is None:
-            if branch.last_revision() != None:
+            if not is_null(branch.last_revision()):
                 raise NotPreviousImport(branch.base)
         elif version is None:
             version = last_patch.version
@@ -449,7 +449,7 @@ def import_version(output_dir, version, encoding, fast=False,
             if wt is not None:
                 wt.set_last_revision(wt.branch.last_revision())
                 wt.set_root_id(BAZ_IMPORT_ROOT)
-                wt.revert([])
+                wt.revert()
 
         finally:
 
@@ -514,8 +514,10 @@ def arch_revision(revision_id):
     'None'
     >>> str(arch_revision("Arch-1-utf-8:jrandom@example.com%test--test--0--patch-5")[1])
     'utf-8'
+    >>> str(arch_revision('null:'))
+    '(None, None)'
     """
-    if revision_id is None:
+    if is_null(revision_id):
         return None, None
     if revision_id[:7] not in ('Arch-1:', 'Arch-1-'):
         raise NotArchRevision(revision_id)
@@ -607,8 +609,7 @@ def iter_import_version(output_dir, ancestors, tempdir, pb, encoding,
         else:
             target_branch = create_branch(output_dir)
 
-    for i in range(len(ancestors)):
-        revision = ancestors[i]
+    for i, revision in enumerate(ancestors):
         rev_id = revision_id(revision, encoding)
         direct_merges = []
         if verbose:
@@ -621,7 +622,7 @@ def iter_import_version(output_dir, ancestors, tempdir, pb, encoding,
             yield Progress("revisions", i, len(ancestors))
 
         if target_branch.repository.has_revision(rev_id):
-            target_branch.append_revision(rev_id)
+            target_branch.set_last_revision_info(i+1, rev_id)
             continue
         if revdir is None:
             revdir = os.path.join(tempdir, "rd")
