@@ -78,7 +78,8 @@ def get_push_data(tree):
     >>> rm_tree(tree)
     """
     try:
-        location = tree.branch.control_files.get_utf8('x-push-data').read()
+        location = tree.branch.control_files.get('x-push-data').read()
+        location = location.decode('utf-8')
     except NoSuchFile:
         return None
     return location.rstrip('\n')
