@@ -20,7 +20,7 @@ from dotgraph import RSVG_OUTPUT_TYPES, DOT_OUTPUT_TYPES, Edge, invoke_dot_html
 from bzrlib.branch import Branch
 from bzrlib.errors import BzrCommandError, NoCommonRoot, NoSuchRevision
 from bzrlib.graph import node_distances, select_farthest
-from bzrlib.revision import combined_graph, revision_graph
+from bzrlib.revision import combined_graph, revision_graph, NULL_REVISION
 from bzrlib.revision import MultipleRevisionSources
 import bzrlib.errors
 import re
@@ -106,25 +106,20 @@ def get_rev_info(rev_id, source):
     return committer, message, nick, date
 
 class Grapher(object):
+
     def __init__(self, branch, other_branch=None):
         object.__init__(self)
         self.branch = branch
         self.other_branch = other_branch
-        revision_a = self.branch.last_revision()
         if other_branch is not None:
-            branch.fetch(other_branch)
+            other_repo = other_branch.repository
             revision_b = self.other_branch.last_revision()
-            try:
-                self.root, self.ancestors, self.descendants, self.common = \
-                    combined_graph(revision_a, revision_b,
-                                   self.branch.repository)
-            except bzrlib.errors.NoCommonRoot:
-                raise bzrlib.errors.NoCommonAncestor(revision_a, revision_b)
         else:
-            self.root, self.ancestors, self.descendants = \
-                revision_graph(revision_a, branch.repository)
-            self.common = []
-
+            other_repo = None
+            revision_b = None
+        self.graph = self.branch.repository.get_graph(other_repo)
+        revision_a = self.branch.last_revision()
+        self.scan_graph(revision_a, revision_b)
         self.n_history = branch.revision_history()
         self.n_revnos = branch.get_revision_id_to_revno_map()
         self.distances = node_distances(self.descendants, self.ancestors,
@@ -133,14 +128,9 @@ class Grapher(object):
             self.base = select_farthest(self.distances, self.common)
             self.m_history = other_branch.revision_history()
             self.m_revnos = other_branch.get_revision_id_to_revno_map()
-            new_graph = getattr(branch.repository, 'get_graph', lambda: None)()
-            if new_graph is None:
-                self.new_base = None
-                self.lcas = set()
-            else:
-                self.new_base = new_graph.find_unique_lca(revision_a,
-                                                          revision_b)
-                self.lcas = new_graph.find_lca(revision_a, revision_b)
+            self.new_base = self.graph.find_unique_lca(revision_a,
+                                                       revision_b)
+            self.lcas = self.graph.find_lca(revision_a, revision_b)
         else:
             self.base = None
             self.new_base = None
@@ -148,6 +138,30 @@ class Grapher(object):
             self.m_history = []
             self.m_revnos = {}
 
+    def scan_graph(self, revision_a, revision_b):
+        a_ancestors = dict(self.graph.iter_ancestry([revision_a]))
+        self.ancestors = a_ancestors
+        self.root = NULL_REVISION
+        if revision_b is not None:
+            b_ancestors = dict(self.graph.iter_ancestry([revision_b]))
+            self.common = set(a_ancestors.keys())
+            self.common.intersection_update(b_ancestors)
+            self.ancestors.update(b_ancestors)
+        else:
+            self.common = []
+            revision_b = None
+        self.descendants = {}
+        ghosts = set()
+        for revision, parents in self.ancestors.iteritems():
+            self.descendants.setdefault(revision, [])
+            if parents is None:
+                ghosts.add(revision)
+                parents = [NULL_REVISION]
+            for parent in parents:
+                self.descendants.setdefault(parent, []).append(revision)
+        for ghost in ghosts:
+            self.ancestors[ghost] = [NULL_REVISION]
+
     @staticmethod
     def _get_revno_str(prefix, revno_map, revision_id):
         try:
@@ -322,4 +336,3 @@ def write_ancestry_file(branch, filename, collapse=True, antialias=True,
                 " is installed correctly.")
     elif not done:
         print "Unknown file extension: %s" % ext
-
