@@ -31,12 +31,15 @@ if os.path.exists(final_name):
 if call(['bzr', 'diff'], stdout=PIPE) != 0:
     print "Please commit before releasing"
     sys.exit(1)
+retcode = call(['bzr', 'tag', 'release-%s' % bzrtools.__version__])
+if retcode != 0:
+    sys.exit(1)
 retcode = call(['bzr', 'export', '../bzrtools.tar.gz'])
 if retcode != 0:
     sys.exit(1)
 os.rename('../bzrtools.tar.gz', final_name)
 print 'Created %s' % final_name
 call(['gpg', '--detach-sign', final_name])
-print 'Uploading...'
-call(['scp', final_name, final_name + '.sig',
-      'panoramicfeedback.com:opensource/'])
+#print 'Uploading...'
+#call(['scp', final_name, final_name + '.sig',
+#      'panoramicfeedback.com:opensource/'])
