@@ -75,8 +75,9 @@ class cmd_show_paths(BzrToolsCommand):
 
         from bzrlib.branch import Branch
         from bzrlib.errors import NotBranchError, NoWorkingTree
-        from bzrlib import urlutils
+        from bzrlib import urlutils, trace
         from bzrlib.workingtree import WorkingTree
+        trace.warning('This command is obsolete.  Use "bzr info" instead.')
 
         def local_path(path):
             if path.startswith("file://"):
