@@ -624,3 +624,7 @@ class ShelfTests(bzrlib.tests.TestCaseWithTransport):
     def test_shelf_help(self):
         self.assertContainsRe(cmd_shelf().help(),
                               'list\n.*List the patches on the current shelf')
+
+    def test_show_empty_shelf(self):
+        self.tree = self.make_branch_and_tree('.')
+        self.run_bzr_error(('No patches on shelf.',), 'shelf show')
