@@ -741,7 +741,7 @@ class TestImport(TestCaseInTempDir):
         command.run(os.path.join(self._tmpdir, 'output'), 'demo@DONOTUSE')
         self.failUnless(os.path.exists(os.path.join(self._tmpdir,'output')))
         walk_len = len(list(os.walk(os.path.join(self._tmpdir,'output'))))
-        self.assertEqual(7, walk_len)
+        self.assertEqual(9, walk_len)
 
     def test_two_branches(self):
         self.make_import('c--0')
@@ -754,12 +754,8 @@ class TestImport(TestCaseInTempDir):
         self.failUnless(os.path.exists(os.path.join(self._tmpdir,'output',
                                                     'c1', '0.2','branch')))
         default_format = repository.RepositoryFormat.get_default_format()
-        if getattr(default_format, 'rich_root_data', False):
-            num_files = 21
-        else:
-            num_files = 20
         walk_len = len(list(os.walk(os.path.join(self._tmpdir,'output'))))
-        self.assertEqual(num_files, walk_len)
+        self.assertEqual(22, walk_len)
 
     def test_run_twice(self):
         self.make_import('c--0')
