@@ -12,7 +12,7 @@ from errors import (NotCheckout, UncommittedCheckout, ParentMissingRevisions,
                     NoParent)
 
 
-def zap(path, remove_branch=False):
+def zap(path, remove_branch=False, allow_modified=False):
     try:
         wt = bzrdir.BzrDir.open(path).open_workingtree(path,
                                                        recommend_upgrade=False)
@@ -23,9 +23,10 @@ def zap(path, remove_branch=False):
     branch_base = branch.bzrdir.transport.base
     if tree_base == branch_base:
         raise NotCheckout(path)
-    delta = wt.changes_from(wt.basis_tree(), want_unchanged=False)
-    if delta.has_changed():
-        raise UncommittedCheckout()
+    if not allow_modified:
+        delta = wt.changes_from(wt.basis_tree(), want_unchanged=False)
+        if delta.has_changed():
+            raise UncommittedCheckout()
     if remove_branch:
         parent_loc = branch.get_parent()
         if parent_loc is None:
@@ -101,4 +102,11 @@ def test_suite():
             checkout.commit('commit changes to branch')
             zap('checkout')
 
+        def test_allow_modified(self):
+            checkout = self.make_checkout()
+            os.mkdir('checkout/foo')
+            checkout.add('foo')
+            self.assertRaises(UncommittedCheckout, zap, 'checkout')
+            zap('checkout', allow_modified=True)
+
     return makeSuite(TestZap)
